#
# spec file for package python-qtconsole
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1500
%bcond_without libalternatives
%else
%bcond_with libalternatives
%endif
Name:           python-qtconsole
Version:        5.6.1
Release:        1.3
Summary:        Jupyter Qt console
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/jupyter/qtconsole
Source0:        https://files.pythonhosted.org/packages/source/q/qtconsole/qtconsole-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module jupyter-core}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gdb
BuildRequires:  hicolor-icon-theme
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
# QtPy does note require or depend on one of the frameworks itself
Requires:       (python-qt5 or python-pyside2 or python-PyQt6 or python-pyside6)
Requires:       python-Pygments
Requires:       python-QtPy >= 2.4.0
Requires:       python-ipykernel >= 4.1
Requires:       python-jupyter-client >= 4.1
Requires:       python-jupyter-core
Requires:       python-packaging
Requires:       python-traitlets
Conflicts:      python-traitlets = 5.2.1
Conflicts:      python-traitlets = 5.2.2
Provides:       python-jupyter_qtconsole = %{version}
Obsoletes:      python-jupyter_qtconsole < %{version}
BuildArch:      noarch
%if "%{python_flavor}" == "%{primary_python}"
Provides:       jupyter-qtconsole = %{version}-%{release}
Obsoletes:      jupyter-qtconsole < %{version}-%{release}
%endif
%if %{with libalternatives}
BuildRequires:  alts
Requires:       alts
%else
Requires(post): update-alternatives
Requires(postun): update-alternatives
%endif
# SECTION test requirements
BuildRequires:  %{python_module Pygments}
BuildRequires:  %{python_module QtPy >= 2.4.0}
BuildRequires:  %{python_module flaky}
BuildRequires:  %{python_module ipykernel >= 4.1}
BuildRequires:  %{python_module jupyter-client >= 4.1}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module pytest-qt}
BuildRequires:  %{python_module pytest-xvfb}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module qt5}
BuildRequires:  %{python_module traitlets}
# /SECTION
%python_subpackages

%description
A rich Qt-based console for working with Jupyter kernels,
supporting rich media output, session export, and more.

%prep
%setup -q -n qtconsole-%{version}

%build
%pyproject_wheel

%install
export LANG=en_US.UTF-8
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%python_clone -a %{buildroot}%{_bindir}/jupyter-qtconsole

# Install icon
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/
%python_expand cp qtconsole/resources/icon/JupyterConsole.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/JupyterQtConsole-%{$python_bin_suffix}.svg

# Modify and install .desktop file
pushd examples
%{python_expand # clone desktop file for flavors
f=jupyter-qtconsole-%{$python_bin_suffix}.desktop
cp jupyter-qtconsole.desktop $f
desktop-file-edit \
  --set-icon="JupyterQtConsole-%{$python_bin_suffix}" \
  --set-key=Exec --set-value="jupyter-qtconsole-%{$python_bin_suffix}" \
  $f
desktop-file-install $f
}
popd

%check
%pytest -ra

%pre
%python_libalternatives_reset_alternative jupyter-qtconsole

%post
%python_install_alternative jupyter-qtconsole

%postun
%python_uninstall_alternative jupyter-qtconsole

%files %{python_files}
%license LICENSE
%python_alternative %{_bindir}/jupyter-qtconsole
%{_datadir}/applications/jupyter-qtconsole-%{python_bin_suffix}.desktop
%{_datadir}/icons/hicolor/scalable/apps/JupyterQtConsole-%{python_bin_suffix}.svg
%{python_sitelib}/qtconsole-%{version}*-info
%{python_sitelib}/qtconsole/

%changelog
* Sun Nov 17 2024 Ben Greiner <code@bnavigator.de>
- Update to 5.6.1
  * Handle ANSI escape sequences that move the cursor.
- Remove deprecated %%suse_update_desktop_file
  * https://en.opensuse.org/openSUSE:Update-desktop-files_deprecation
  * nothing relevant to upstream
* Sun Sep  8 2024 Ben Greiner <code@bnavigator.de>
- Update to 5.6.0
  * Use selected syntax highlighting style for tracebacks and
    improve ANSI color codes support.
  * Remove syntax highlighting support for Python 2.
  * Fix handling of carriage return.
  * Fix showing bold face characters in output when using ANSI
    codes.
* Fri Jul 12 2024 Ben Greiner <code@bnavigator.de>
- Update to 5.5.2
  * Check if kernel manager is available in case the console is
    connected to an externally launched kernel.
  * Use string representation for a QKeySequence construction to
    avoid an error in PySide6.
* Fri Mar  8 2024 Ben Greiner <code@bnavigator.de>
- Skip python39: no longer supported since ipython 8.19
  (via ipykernel)
* Fri Nov 24 2023 Ben Greiner <code@bnavigator.de>
- Update to 5.5.1
  * Fix error when getting code completions.
- Release 5.5.0
  * Drop support for Python 3.7.
  * Remove ipython_genutils as a dependency.
* Sun Sep 24 2023 Ben Greiner <code@bnavigator.de>
- Update to 5.4.4
  * Improve compatibility with PyQt6/PySide6.
* Fri Jun  2 2023 Ben Greiner <code@bnavigator.de>
- Update to 5.4.3
  * Add missing closed method to QtInProcessChannel.
* Sun Apr 23 2023 Ben Greiner <code@bnavigator.de>
- Update to 5.4.2
  * Check if the iopub channel is not closed before flushing it
  * Fix kernel autorestart after it's killed for Jupyter-client 8+
* Sun Mar 19 2023 Ben Greiner <code@bnavigator.de>
- Update to 5.4.1
  * Fix crash at startup with PySide6.
  * Cast images width and height to int when trying to insert them.
* Sat Nov  5 2022 Arun Persaud <arun@gmx.de>
- update to version 5.4.0:
  * Additions
    + Add ConsoleWidget.gui_completion_height option to configure the
    maximum number of rows or height in pixels of completions when
    the ConsoleWidget.gui_completion option has values 'ncurses' or
    'droplist', respectively.
  * Changes
    + Fix some errors with PySide6 6.4.0.
    + Fix mixed input and print statements on macOS.
    + Drop usage of disutils.
* Sun Aug 28 2022 Ben Greiner <code@bnavigator.de>
- Update to version 5.3.2
  * Fix syntax highlighting with multiline inputs.
- Test with xvfb display
- Remove skip of previously segfaulting tests
- Allow PyQt6 and Pyside6 as backend
- Add missing pyzmq requirement (was already transitive)
- Remove obsolete jupyter package, provide desktop files and icon
  for every flavor
* Wed Jun 22 2022 Arun Persaud <arun@gmx.de>
- update to version 5.3.1:
  * Fix segfault when performing code completion on Qt6.
  * Fix mixed input and print statements.
  * Fix switching syntax highlighting styles on PySide2 and PySide6.
* Sat Apr  9 2022 Ben Greiner <code@bnavigator.de>
- Update to version 5.3.0
  * Add support for PyQt6.
  * Don't show spurious blank lines when running input statements.
  * Fix showing Latex images with dark background colors.
  * Drop support for Python 3.6
* Thu Feb  3 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 5.2.2:
  * Fix implicit int to float conversion for Python 3.10
    compatibility.
  * Fix building documentation in ReadTheDocs.
* Fri Nov 26 2021 Ben Greiner <code@bnavigator.de>
- Update to version 5.2.1
  * Fix error when deleting CallTipWidget.
  * Another fix for the 'Erase in Line' ANSI code.
- Enable libalternatives as with the rest of the jupyter commands
* Sun Nov 14 2021 Ben Greiner <code@bnavigator.de>
- Update to version 5.2.0
  * Fix hidden execution requests.
  * Fix ANSI code for erase line.
* Fri Oct 29 2021 Ben Greiner <code@bnavigator.de>
- Require a Qt backend. boo#1136083
* Sun Oct 10 2021 Ben Greiner <code@bnavigator.de>
- Update to version 5.1.1
  * Improve handling of different keyboard combinations.
  * Move cursor to the beginning of buffer if on the same line.
* Mon May 10 2021 Ben Greiner <code@bnavigator.de>
- Update to version 5.1.0
  * Two new keyboard shortcuts: Ctrl + Up/Down to go to the
    beginning/end of the buffer.
  * Monkeypatch RegexLexer only while in use by qtconsole.
  * Import Empty from queue module.
* Fri Mar 19 2021 Ben Greiner <code@bnavigator.de>
- Update to version 5.0.3
  * Emit kernel_restarted signal only after a kernel crash.
- move u-a scriptlets to the correct package
* Sat Jan 30 2021 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 5.0.2:
  * Fix launching issue with Big Sur
  * Remove partial prompt on copy
* Tue Dec 15 2020 Benjamin Greiner <code@bnavigator.de>
- Move the alternative binary to the flavored python package
* Thu Nov 26 2020 Arun Persaud <arun@gmx.de>
- update to version 5.0.1:
  * Add python_requires to setup.py for Python 3.6+ compatibility
- changes from version 5.0.0:
  * Additions
    + Add option to set completion type while running.
  * Changes
    + Emit kernel_restarted after restarting kernel.
    + Drop support for Python 2.7 and 3.5.
* Wed Sep 16 2020 Benjamin Greiner <code@bnavigator.de>
- skip two tests: gh#jupyter/qtconsole#443
* Sat Sep  5 2020 Arun Persaud <arun@gmx.de>
- update to version 4.7.7:
  * Change font width calculation to use horizontalAdvance
* Fri Aug 28 2020 Benjamin Greiner <code@bnavigator.de>
- Update to 4.7.6
  * Replace qApp with QApplication.instance().
  * Fix QFontMetrics.width deprecation.
- use alternatives for entry point
- SIP is not used anymore
* Wed Jul  1 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 4.7.5
  * Print input if there is no prompt.
* Sat May 23 2020 Arun Persaud <arun@gmx.de>
- update to version 4.7.4:
  * Fix completion widget text for paths and files.
  * Make Qtconsole work on Python 3.8 and Windows.
* Sat Apr 18 2020 Arun Persaud <arun@gmx.de>
- update to version 4.7.3:
  * Fix all misuses of QtGui.
* Sat Mar 28 2020 Arun Persaud <arun@gmx.de>
- update to version 4.7.2:
  * Set updated prompt as previous prompt object in JupyterWidget.
  * Fix some Qt incorrect imports.
* Thu Mar 12 2020 Arun Persaud <arun@gmx.de>
- update to version 4.7.1:
  * Remove common prefix from path completions.
  * Use QtWidgets instead of QtGui to create QMenu instances.
* Tue Mar  3 2020 Todd R <toddrme2178@gmail.com>
- Update to version 4.7.0
  + Additions
  * Use qtpy as the shim layer for Python Qt bindings and remove our own shim.
  + Changes
  * Remove code to expand tabs to spaces.
  * Skip history if it is the same as the input buffer.
- Drop doc subpackage due to rapid changes in readthedocs download
  urls.  This was a hold-over from when the tests were run in a
  separate doc subpackage.
* Fri Nov 22 2019 Todd R <toddrme2178@gmail.com>
- Update to version 4.6.0
  + Additions
  * Add an option to configure scrollbar visibility.
  + Changes
  * Avoid introducing a new line when executing code.
* Tue Nov 12 2019 Todd R <toddrme2178@gmail.com>
- Update to version 4.5.5
  * Set console to read only after input.
  * Allow text to be added before the prompt while autocompleting.
  * Scroll when adding text even when not executing.
- Update to versionn 4.5.4
  * Fix emoji highlighting.
- Update to versionn 4.5.3
  * Fix error when closing comms.
  * Fix prompt automatically scrolling down on execution.
* Mon Jul 29 2019 Todd R <toddrme2178@gmail.com>
- Update to versionn 4.5.2
  * Remove deprecation warnings in Python 3.8
  * Improve positioning and content of completion widget.
  * Scroll down for output from remote commands.
* Wed Jun 12 2019 Todd R <toddrme2178@gmail.com>
- Update to version 4.5.1
  * Only use setuptools in setup.py to fix uploading tarballs to PyPI.
- Update to version 4.5
  + Additions
  * Add Comms to qtconsole.
  * Add kernel language name as an attribute of JupyterWidget.
  + Changes
  * Use new traitlets API with decorators.
* Thu Apr 25 2019 Todd R <toddrme2178@gmail.com>
- Rename to to match python package naming guidelines.
- Split jupyter components into own subpackage.
- Update to version 4.4.4
  * Prevent cursor from moving to the end of the line while debugging.
* Sat Dec 22 2018 Todd R <toddrme2178@gmail.com>
- Update to version 4.4.3
  * Fix complete statements check inside indented block for Python after the IPython 7 release.
  * Improve auto-scrolling during execution.
- Update to version 4.4.2
  * Fix incompatibility with PyQt5 5.11.
* Fri Sep  7 2018 toddrme2178@gmail.com
- Update to version 4.4.1
  * Fix setting width and height when displaying images with IPython's Image.
  * Avoid displaying errors when using Matplotlib to generate pngs from Latex.
- Update to version 4.4.0
  + Additions
  * :kbd:`Control-D` enters an EOT character if kernel is executing and input is empty.
  * Implement block indent on multiline selection with :kbd:`Tab`.
- Change the syntax highlighting style used in the console at any time. It can
  be done in the menu ``View > Syntax Style``.
  + Changes
  * Change :kbd:`Control-Shift-A` to select cell contents first.
  * Change default tab width to 4 spaces.
  * Enhance handling of input from other clients.
- Don't block the console when the kernel is asked for completions.
  + Fixes
  * Fix bug that make PySide2 a forbidden binding.
  * Fix IndexError when copying prompts.
  * Fix behavior of right arrow key.
  * Fix behavior of :kbd:`Control-Backspace` and :kbd:`Control-Del`
- Use upstream documentation builds
* Tue Feb 13 2018 toddrme2178@gmail.com
- Update url
* Tue Sep 19 2017 toddrme2178@gmail.com
- Update to 4.3.1
  * Make %%clear to delete previous output on Windows.
  * Fix SVG rendering.
* Wed Apr 26 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Fri Apr  7 2017 toddrme2178@gmail.com
- Fix update-alternatives usage.
* Thu Mar 30 2017 toddrme2178@gmail.com
- Update to 4.3
  + Additions
  * Add :kbd:`Shift-Tab` shortcut to unindent text
  * Add :kbd:`Control-R` shortcut to rename the current tab
  * Add :kbd:`Alt-R` shortcut to set the main window title
  * Add :kbd:`Command-Alt-Left` and :kbd:`Command-Alt-Right` shortcut to switch
    tabs on macOS
  * Add support for PySide2
  * Add support for Python 3.5
  * Add support for 24 bit ANSI color codes
  * Add option to create new tab connected to the existing kernel
  + Changes
  * Change :kbd:`Tab` key behavior to always indent to the next increment of 4 spaces
  * Change :kbd:`Home` key behavior to alternate cursor between the beginning of text
    (ignoring leading spaces) and beginning of the line
  * Improve documentation of various options and clarified the docs in some places
  * Move documentation to ReadTheDocs
  * Rename `ConsoleWidget.width/height` traits to `console_width/console_height`
    to avoid a name clash with the `QWidget` properties. Note: the name change
    could be, in rare cases if a name collision exists, a code-breaking
    change.
  + Fixes
  * Fix automatic indentation of new lines that are inserted in the middle of a
    cell
  * Fix regression where prompt would never be shown for `--existing` consoles
  * Fix `python.exe -m qtconsole` on Windows
  * Fix showing error messages when running a script using `%%run`
  * Fix `invalid cursor position` error and subsequent freezing of user input
  * Fix syntax coloring when attaching to non-IPython kernels
  * Fix printing when using QT5
  * Fix :kbd:`Control-K` shortcut (delete until end of line) on macOS
  * Fix history browsing (:kbd:`Up`/:kbd:`Down` keys) when lines are longer than
    the terminal width
  * Fix saving HTML with inline PNG for Python 3
  * Various internal bugfixes
- Update to 4.2
  * various latex display fixes
  * improvements for embedding in Qt applications (use existing Qt API if one is already loaded)
* Thu Feb 18 2016 toddrme2178@gmail.com
- update to version 4.1.1:
  * Set AppUserModelID for Windows 7 and later
  * Switch to using qtconsole module to find qt
  * Fix Travis tests for Python 2
  * Updated example for creating inprocess qtconsole
  * Enable 3.5 on travis
- Split documentation into subpackage
* Fri Oct 16 2015 toddrme2178@gmail.com
- Update to 4.1.0
  * Fixed generating the default configuration
  * Fixed some regressions in copy/paste from the console.
* Mon Oct  5 2015 toddrme2178@gmail.com
- Build documentation
* Fri Aug 21 2015 toddrme2178@gmail.com
- Remove duplicate requirements
* Thu Aug 13 2015 toddrme2178@gmail.com
- Initial version
